@@ -8,6 +8,9 @@ class Instantiate(Function):
             obj = cls()
             method = getattr(obj, self._method)
             return method(*args, **kw)
+        _func.__name__ = cls.__name__
+        _func.__module__ = cls.__module__
+        _func.__doc__ = cls.__doc__
         return super(Instantiate, self)._decorate(_func)
     
     def _init(self, method='__call__'):
